@@ -1,46 +1,16 @@
 """Caching functions for the Github Auth module."""
 
-import asyncio
 import hashlib
 import pickle  # noqa: S403
-import warnings
 from pathlib import Path
-from typing import Any, Dict
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, TypeVar
 
 from cachetools import TTLCache
 from dogpile.cache import CacheRegion, make_region, register_backend
-from dogpile.cache.api import NO_VALUE, CacheBackend
+from dogpile.cache.api import NO_VALUE, BackendFormatted, BackendSetType, CacheBackend, CachedValue
 from dogpile.cache.util import compat
-from makefun import wraps
 
-
-class CoroutineCache:
-    def __init__(self, co):
-        self.co = co
-        self.done = False
-        self.result = None
-        self.lock = asyncio.Lock()
-
-    def __await__(self):  # noqa: WPS611 - `yield` magic method usage
-        # We catch the warnings here because this is a sync function
-        # and we can't use `async with self.lock`
-        with warnings.catch_warnings():
-            warnings.simplefilter('ignore', category=DeprecationWarning)
-            with (yield from self.lock):
-                if self.done:
-                    return self.result
-                self.result = yield from self.co.__await__()  # noqa: WPS609 - direct magic attribute usage
-                self.done = True
-                return self.result
-
-
-def cache_async(f):
-    @wraps(f)
-    def wrapped(*args, **kwargs):
-        r = f(*args, **kwargs)
-        return CoroutineCache(r)
-
-    return wrapped
+R = TypeVar('R')
 
 
 def get_cache_region():
@@ -49,7 +19,7 @@ def get_cache_region():
 
 # This is a copy of the default key generator from dogpile, but
 # with additional hashing to avoid using sensitive values as cache keys
-def cache_key_generator(namespace, fn, to_str=str):
+def cache_key_generator(namespace: Optional[str], fn: Callable[..., Any], to_str: Callable[[object], str] = str):
     if namespace is None:
         namespace = f'{fn.__module__}:{fn.__name__}'  # noqa: WPS609 - direct magic attribute usage
     else:
@@ -57,9 +27,9 @@ def cache_key_generator(namespace, fn, to_str=str):
 
     # Remove the `self` argument, since it'll always change
     fn_args = compat.inspect_getargspec(fn)
-    has_self = fn_args[0] and fn_args[0][0] in {'self', 'cls'}
+    has_self = fn_args[0] and (fn_args[0][0] in {'self', 'cls'})  # type: ignore
 
-    def generate_key(*args, **kw):
+    def generate_key(*args: object, **kw: object) -> str:
         if kw:
             raise ValueError('The dogpile.cache default key creation function does not accept keyword arguments.')
         if has_self:
@@ -118,12 +88,26 @@ def configure_cache_region(cache_region: CacheRegion, settings: Dict[str, Any],
     )
 
 
+if TYPE_CHECKING:  # pragma: no cover
+    StringIndexedTTLCache = TTLCache[str, CachedValue]
+else:
+    StringIndexedTTLCache = TTLCache
+
+
 class TTLBackend(CacheBackend):
     _cache_path = 'cache_path'
+    cache: StringIndexedTTLCache
+    persisted_cache_path: Optional[str]
 
-    def __init__(self, arguments):
+    def __init__(self, arguments: Dict[str, Any]):
+        p_cache_path = arguments.pop(self._cache_path, None)
 
-        self.persisted_cache_path = arguments.pop(self._cache_path, None)
+        if isinstance(p_cache_path, str):
+            self.persisted_cache_path = p_cache_path
+        else:
+            self.persisted_cache_path = None
+
+        # A potentially persisted cache for all items to keep in cache
         self.cache = TTLCache(**arguments)
 
         if self.persisted_cache_path:
@@ -139,20 +123,27 @@ class TTLBackend(CacheBackend):
             except (FileNotFoundError, EOFError):
                 pass
 
-    def get(self, key):
-        return self.cache.get(key, NO_VALUE)
+    def get(self, key: str) -> BackendFormatted:
+        val = self.cache.get(key, NO_VALUE)
+        if isinstance(val, NO_VALUE.__class__):
+            return val
+        return val
+
+    def set(self, key: str, value: BackendSetType) -> None:  # noqa: WPS125, A003
+        if not isinstance(value, CachedValue):  # pragma: no cover
+            value = CachedValue(value, {})
 
-    def set(self, key, value):  # noqa: WPS125, A003
         self.cache[key] = value
         if self.persisted_cache_path:
             self.persist_cache()
 
-    def delete(self, key):
-        self.cache.pop(key)
-        if self.persisted_cache_path:
+    def delete(self, key: str):
+        sentinel = object()
+        if self.cache.pop(key, sentinel) is not sentinel and self.persisted_cache_path:
             self.persist_cache()
 
     def persist_cache(self):
+        assert self.persisted_cache_path
         with open(self.persisted_cache_path, 'wb') as f:
             pickle.dump(self.cache, f)
 
