@@ -20,7 +20,7 @@ Example:
 import asyncio
 from contextlib import contextmanager
 from functools import wraps
-from typing import Any, Callable, Protocol, Type, TypeVar, cast
+from typing import Any, Callable, Generic, Protocol, Type, TypeVar, cast
 
 SE = TypeVar('SE', bound=Exception)
 TE = TypeVar('TE', bound=Exception)
@@ -36,17 +36,18 @@ class Decorator(Protocol):  # pragma: no cover
         ...
 
 
-def default_mapper(ex: Exception, target_exc: Type[TE]) -> TE:  # pragma: no-cover-for-integration
-    """Default mapper that doesn't attempt to preserve any information. Just instantiates a TargetExClass.
+class DefaultMapper(Generic[TE]):  # pragma: no-cover-for-integration
+    def __call__(self, ex: Exception, target_exc: Type[TE]) -> TE:
+        """Default mapper that doesn't attempt to preserve any information. Just instantiates a TargetExClass.
 
-    Args:
-        ex (Exception): The source exception.
-        target_exc (TE): The target Exception class.
+        Args:
+            ex (Exception): The source exception.
+            target_exc (TE): The target Exception class.
 
-    Returns:
-        TE: An instance of the provided tartget Exception class.
-    """
-    return target_exc()
+        Returns:
+            TE: An instance of the provided tartget Exception class.
+        """
+        return target_exc()
 
 
 # Actually performs the catching and remapping, shouldn't be called directly
@@ -63,7 +64,7 @@ def remap_exception(
 
 
 def reraise_as(  # noqa: WPS212
-    source_exc: Type[SE], target_exc: Type[TE], mapper: Mapper[SE, TE] = default_mapper,
+    source_exc: Type[SE], target_exc: Type[TE], mapper: Mapper[SE, TE] = DefaultMapper[TE](),
 ) -> Decorator:  # pragma: no-cover-for-integration
     """A decorator function that intercepts raised Exceptions and maps them to a different Exception class.
 
